==> tikiwiki-9.2.tbz: www/tikiwiki-9.2/lib/prefs/share.php <==
<?php
// (c) Copyright 2002-2012 by authors of the Tiki Wiki CMS Groupware Project
// 
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: share.php 39469 2012-01-12 21:13:48Z changi67 $

function prefs_share_list()
{
	return array(
		'share_display_links' => array(
			'name' => tra('Display links in the share page'),
			'type' => 'flag',
			'default' => 'y',
		),
		'share_token_notification' => array(
			'name' => tra('Token notification'),
			'description' => tra('Users can subscribe to the notifications of consultation of the token'),
			'type' => 'flag',
			'perspective' => false,
			'dependencies' => array(
				'auth_token_access'
			),
			'default' => 'y',
		),
		'share_contact_add_non_existant_contact' => array(
			'name'	=> tra('Add contact'),
			'description' => tra('If not exist, recipients are add in the list of contacts'),
			'type' => 'flag',
			'perspective' => false,
			'dependencies' => array(
				'feature_contacts',
			),
			'default' => 'n',
		),
		'share_display_name_and_email' => array(
			'name' => tra('Display name and email'),
			'description' => tra('If user is connect, name and email display in the page'),
			'type' => 'flag',
			'default' => 'y',
		),
		'share_can_choose_how_much_time_access' => array(
			'name' => tra('How much time access'),
			'description' => tra('User can choose how much time the share page can be consult'),
			'type' => 'flag',
			'dependencies' => array(
				'auth_token_access',
			),
			'default' => 'n',
		),
		'share_max_access_time' => array(
			'name' => tra('Max how much time access'),
			'description' => tra('Maximum for select how much time the share page can be consult'),
			'type' => 'text',
			'default' => '-1',
		),
		
	);
}

==> tikiwiki-11.0.tbz: www/tikiwiki-11.0/lib/prefs/share.php <==
<?php
// (c) Copyright 2002-2013 by authors of the Tiki Wiki CMS Groupware Project
// 
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: share.php 46252 2013-06-10 09:39:33Z xavidp $

function prefs_share_list()
{
	return array(
		'share_display_links' => array(
			'name' => tra('Display links in the share page'),
			'type' => 'flag',
			'default' => 'y',
		),
		'share_token_notification' => array(
			'name' => tra('Token notification'),
			'description' => tra('Users can subscribe to the notifications of consultation of the token'),
			'type' => 'flag',
			'perspective' => false,
			'dependencies' => array(
				'auth_token_access'
			),
			'default' => 'y',
		),
		'share_contact_add_non_existant_contact' => array(
			'name'	=> tra('Add contact'),
			'description' => tra('If not exist, recipients are add in the list of contacts'),
			'type' => 'flag',
			'perspective' => false,
			'dependencies' => array(
				'feature_contacts',
			),
			'default' => 'n',
		),
		'share_display_name_and_email' => array(
			'name' => tra('Display name and email'),
			'description' => tra('If user is connect, name and email display in the page'),
			'type' => 'flag',
			'default' => 'y',
		),
		'share_can_choose_how_much_time_access' => array(
			'name' => tra('How many times accessed'),
			'description' => tra('User can choose how many times the share page can be consulted'),
			'type' => 'flag',
			'dependencies' => array(
				'auth_token_access',
			),
			'default' => 'n',
		),
		'share_max_access_time' => array(
			'name' => tra('Max how many times accessed'),
			'description' => tra('Maximum number of times that the shared page can be consulted'),
			'type' => 'text',
			'default' => '-1',
		),
		
	);
}
